@@ -3,6 +3,7 @@
 
 #include <cmath>
 #include <cstddef>
+#include <limits>
 #include <stdexcept>
 #include <sstream>
 #include <vector>
@@ -12,6 +13,7 @@
 #include <stan/agrad/matrix.hpp>
 #include <stan/math.hpp>
 #include <stan/math/matrix.hpp>
+#include <stan/math/matrix/sum.hpp>
 #include <stan/math/matrix/validate_less.hpp>
 #include <stan/math/error_handling.hpp>
 #include <stan/math/matrix_error_handling.hpp>
@@ -381,7 +383,7 @@ namespace stan {
      * placeholder in auto-generated code.
      *
      * @param x Free scalar.
-     * @param lp Reference to log probability.
+     * lp Reference to log probability.
      * @return Transformed input.
      * @tparam T Type of scalar.
      */
@@ -980,7 +982,7 @@ namespace stan {
      * Return the unit length vector corresponding to the free vector y.
      * The free vector contains K-1 spherical coordinates.
      *
-     * @param Vector of K - 1 spherical coordinates
+     * @param y of K - 1 spherical coordinates
      * @return Unit length vector of dimension K
      * @tparam T Scalar type.
      **/
@@ -1005,7 +1007,7 @@ namespace stan {
      * Return the unit length vector corresponding to the free vector y.
      * The free vector contains K-1 spherical coordinates.
      *
-     * @param Vector of K - 1 spherical coordinates
+     * @param y of K - 1 spherical coordinates
      * @return Unit length vector of dimension K
      * @param lp Log probability reference to increment.
      * @tparam T Scalar type.
@@ -1314,6 +1316,116 @@ namespace stan {
     }
     
 
+    // CHOLESKY FACTOR
+
+    /**
+     * Return the Cholesky factor of the specified size read from the
+     * specified vector.  A total of (N choose 2) + N + (M - N) * N
+     * elements are required to read an M by N Cholesky factor.
+     * 
+     * @tparam T Type of scalars in matrix
+     * @param x Vector of unconstrained values
+     * @param M Number of rows
+     * @param N Number of columns
+     * @return Cholesky factor
+     */
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
+    cholesky_factor_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x,
+                              int M,
+                              int N) {
+      using std::exp;
+      if (M < N)
+        throw std::domain_error("cholesky_factor_constrain: num rows must be >= num cols");
+      if (x.size() != ((N * (N + 1)) / 2 + (M - N) * N))
+        throw std::domain_error("cholesky_factor_constrain: x.size() must be (N * (N + 1)) / 2 + (M - N) * N");
+      Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> y(M,N);
+      T zero(0);
+      int pos = 0;
+      // upper square
+      for (int m = 0; m < N; ++m) {
+        for (int n = 0; n < m; ++n)
+          y(m,n) = x(pos++);
+        y(m,m) = exp(x(pos++));
+        for (int n = m + 1; n < N; ++n)
+          y(m,n) = zero;
+      }
+      // lower rectangle
+      for (int m = N; m < M; ++m)
+        for (int n = 0; n < N; ++n)
+          y(m,n) = x(pos++);
+      return y;
+    }
+
+    /**
+     * Return the Cholesky factor of the specified size read from the
+     * specified vector and increment the specified log probability
+     * reference with the log Jacobian adjustment of the transform.  A
+     * total of (N choose 2) + N + N * (M - N) free parameters are required to read
+     * an M by N Cholesky factor.
+     * 
+     * @tparam T Type of scalars in matrix
+     * @param x Vector of unconstrained values
+     * @param M Number of rows
+     * @param N Number of columns
+     * @param lp Log probability that is incremented with the log Jacobian
+     * @return Cholesky factor
+     */
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
+    cholesky_factor_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x,
+                              int M,
+                              int N,
+                              T& lp) {
+      // cut-and-paste from above, so checks twice
+
+      using stan::math::sum;
+      if (x.size() != ((N * (N + 1)) / 2 + (M - N) * N))
+        throw std::domain_error("cholesky_factor_constrain: x.size() must be (k choose 2) + k");
+      int pos = 0;
+      std::vector<T> log_jacobians(N);
+      for (int n = 0; n < N; ++n) {
+        pos += n;
+        log_jacobians[n] = x(pos++);
+      }
+      lp += sum(log_jacobians);  // optimized for autodiff vs. direct lp += 
+      return cholesky_factor_constrain(x,M,N);
+    }
+
+    /**
+     * Return the unconstrained vector of parameters correspdonding to
+     * the specified Cholesky factor.  A Cholesky factor must be lower
+     * triangular and have positive diagonal elements.
+     *
+     * @param y Cholesky factor.
+     * @return Unconstrained parameters for Cholesky factor.
+     * @throw std::domain_error If the matrix is not a Cholesky factor.
+     */
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,1>
+    cholesky_factor_free(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& y) {
+      using std::log;
+      double result;
+      if (!stan::math::check_cholesky_factor("cholesky_factor_free(%1%)",y,"y",&result))
+        throw std::domain_error("cholesky_factor_free: y is not a Cholesky factor");
+      int M = y.rows();
+      int N = y.cols();
+      Eigen::Matrix<T,Eigen::Dynamic,1> x((N * (N + 1)) / 2 + (M - N) * N);
+      int pos = 0;
+      // lower triangle of upper square
+      for (int m = 0; m < N; ++m) {
+        for (int n = 0; n < m; ++n)
+          x(pos++) = y(m,n);
+        // diagonal of upper square
+        x(pos++) = log(y(m,m));
+      }
+      // lower rectangle
+      for (int m = N; m < M; ++m)
+        for (int n = 0; n < N; ++n)
+          x(pos++) = y(m,n);
+      return x;
+    }
+
     // CORRELATION MATRIX
     /**
      * Return the correlation matrix of the specified dimensionality
@@ -1467,7 +1579,7 @@ namespace stan {
         for (size_type n = m + 1; n < K; ++n) 
           L(m,n) = 0.0;
       }
-      Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> M = L * L.transpose();
+      // FIXME: return multiply_self_transpose
       return L * L.transpose();
     }
 
