@@ -3,12 +3,16 @@
 #include <boost/random/mersenne_twister.hpp>
 #include<boost/math/distributions.hpp>
 
-TEST(ProbDistributionsExponential, random) {
+TEST(ProbDistributionsExponential, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::exponential_rng(2.0,rng));
+
+  EXPECT_THROW(stan::prob::exponential_rng(-2.0,rng),std::domain_error);
+  EXPECT_THROW(stan::prob::exponential_rng(stan::math::positive_infinity(),rng),
+               std::domain_error);
 }
 
-TEST(ProbDistributionsBeta, chiSquareGoodnessFitTest) {
+TEST(ProbDistributionsExponential, chiSquareGoodnessFitTest) {
   boost::random::mt19937 rng;
   int N = 10000;
   int K = boost::math::round(2 * std::pow(N, 0.4));
