@@ -3,9 +3,24 @@
 #include <boost/random/mersenne_twister.hpp>
 #include<boost/math/distributions.hpp>
 
-TEST(ProbDistributionsStudentT, random) {
+TEST(ProbDistributionsStudentT, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::student_t_rng(3.0, 2.0, 2.0, rng));
+
+  EXPECT_THROW(stan::prob::student_t_rng(3.0, 2.0, -2.0, rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::student_t_rng(-3.0, 2.0, 2.0, rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::student_t_rng(stan::math::positive_infinity(), 2.0,
+                                         2.0, rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::student_t_rng(3,stan::math::positive_infinity(),
+                                         2.0, rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::student_t_rng(3,2,stan::math::positive_infinity(),
+                                         rng),
+               std::domain_error);
+
 }
 
 TEST(ProbDistributionsStudentT, chiSquareGoodnessFitTest) {
